<?php
// session_start();

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

include 'db.php';

$mlmUserId = $_SESSION['user_id'];

$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $mlmUserId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number'];
} else {
    echo "No user found with the provided ID.";
    exit;
}

$samePhoneQuery = "SELECT `id`, `name`, `phone` FROM `MLM_users` WHERE `phone` = ? AND `id` != ?";
$samePhoneStmt = $conn->prepare($samePhoneQuery);
$samePhoneStmt->bind_param("si", $user['phone'], $mlmUserId);
$samePhoneStmt->execute();
$samePhoneResult = $samePhoneStmt->get_result();
$samePhoneUsers = $samePhoneResult->fetch_all(MYSQLI_ASSOC);

$sql_user = "SELECT name, my_number FROM MLM_users WHERE id = ?";
$userStmt = $conn->prepare($sql_user);
$userStmt->bind_param("i", $mlmUserId);
$userStmt->execute();
$result_user = $userStmt->get_result();

if ($result_user->num_rows > 0) {
    $user = $result_user->fetch_assoc();
    $user_name = $user['name'];
    $my_number = $user['my_number'];
} else {
    echo "User not found!";
    exit;
}

$sql_transactions = "SELECT wallet_type, amount FROM wallet_transactions WHERE user_id = ?";
$transactionStmt = $conn->prepare($sql_transactions);
$transactionStmt->bind_param("i", $mlmUserId);
$transactionStmt->execute();
$result_transactions = $transactionStmt->get_result();

$total_add = 0;
$total_withdrawal = 0;

if ($result_transactions->num_rows > 0) {
    while ($transaction = $result_transactions->fetch_assoc()) {
        if ($transaction['wallet_type'] == 'add') {
            $total_add += $transaction['amount'];
        } elseif ($transaction['wallet_type'] == 'withdrawal') {
            $total_withdrawal += $transaction['amount'];
        }
    }
}

// Calculate total balance
$total_balance = $total_add - $total_withdrawal;
?>

<div class="modal fade" id="switchAccountModal" tabindex="-1" aria-labelledby="switchAccountModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" style="max-width: 400px; width: 100%;">
        <div class="modal-content" style="border-radius: 15px; overflow: hidden;">
            <div class="modal-header border-0 p-3" style="justify-content: space-between;">
                <h5 class="modal-title" id="switchAccountModalLabel" style="font-weight: bold;">Switch Account</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <div id="samePhoneUsers" style="max-height: 300px; overflow-y: auto;">
                    <?php if (!empty($samePhoneUsers)): ?>
                        <?php foreach ($samePhoneUsers as $samePhoneUser): ?>
                            <div class="d-flex align-items-center mb-3 user-option" style="padding: 10px 15px; background-color: #fafafa; border-radius: 10px; cursor: pointer;" data-user-id="<?php echo $samePhoneUser['id']; ?>">
                                <div class="avatar" style="width: 50px; height: 50px;  overflow: hidden;">
                                    <img src="https://hum.ujn.mybluehostin.me/mlm/finapp.bragherstudio.com/Gaurav/main/assets/img/logo.png" alt="User Image" style="width: 40px; height: auto;">
                                </div>
                                <div class="ms-3" style="flex-grow: 1;">
                                    <label class="form-check-label" style="font-weight: 500; font-size: 16px; cursor: pointer;">
                                        <?php echo htmlspecialchars($samePhoneUser['name']); ?>
                                    </label>
                                    <input type="hidden" name="switch_user_id" value="<?php echo $samePhoneUser['id']; ?>">
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <p>No account exists. Please create a new one.</p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    document.querySelectorAll('.user-option').forEach(function(userOption) {
        userOption.addEventListener('click', function() {
            const userId = this.getAttribute('data-user-id');
            fetch('switch_user.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded'
                },
                body: 'switch_user_id=' + userId
            })
            .then(response => response.json())
            .then(data => {
                if (data.status === 'success') {
                    // alert(data.message);
                    window.location.reload(); 
                } else {
                    // alert(data.message);
                }
            })
            .catch(error => console.error('Error:', error));
        });
    });
</script>



<div class="appBottomMenu">
    <a href="index.php" class="item active">
        <div class="col">
            <ion-icon name="pie-chart-outline"></ion-icon>
            <strong>Overview</strong>
        </div>
    </a>
    <a href="" class="item">
        <div class="col">
            <ion-icon name="document-text-outline"></ion-icon>
            <strong>Pages</strong>
        </div>
    </a>
    <a href="index.php" class="item">
        <div class="col">
            <ion-icon name="apps-outline"></ion-icon>
            <strong>Dashboard</strong>
        </div>
    </a>
    <a href="wallet.php" class="item">
        <div class="col">
            <ion-icon name="card-outline"></ion-icon>
            <strong>Wallet</strong>
        </div>
    </a>
    <a class="item">
        <div class="col" data-bs-toggle="modal" data-bs-target="#switchAccountModal">
                                <ion-icon name="person-outline"></ion-icon>
            <strong>Settings</strong>
        </div>
    </a>
</div>



</div>


















<!-- ========= JS Files =========  -->
<!-- Bootstrap -->
<script src="assets/js/lib/bootstrap.bundle.min.js"></script>
<!-- Ionicons -->
<script type="module" src="https://unpkg.com/ionicons@5.5.2/dist/ionicons/ionicons.js"></script>
<!-- Splide -->
<script src="assets/js/plugins/splide/splide.min.js"></script>
<!-- Base Js File -->
<script src="assets/js/base.js"></script>
