<!doctype html>
<html lang="en">

<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1, viewport-fit=cover" />
    <meta name="mobile-web-app-capable" content="yes" />
    <meta name="mobile-web-app-status-bar-style" content="black-translucent">
    <meta name="theme-color" content="#000000">
    <title>Login</title>
    <link rel="icon" type="image/png" href="assets/img/favicon.png" sizes="32x32">
    <link rel="stylesheet" href="assets/css/style.css">
    <style>
        .otp-container {
            display: flex;
            justify-content: space-between;
            margin-top: 10px;
        }

        .otp-input {
            width: 40px;
            height: 40px;
            font-size: 20px;
            text-align: center;
            border: 1px solid #ccc;
            border-radius: 5px;
            margin: 0 5px;
        }

        .otp-input:focus {
            border-color: #007bff;
            outline: none;
        }
    </style>
</head>

<body>

    <div id="appCapsule">
        <div class="section mt-2 text-center">
            <h1>MLM Now</h1>
            <h4>Complete your registration in three easy steps</h4>
        </div>

        <div class="section mb-5 p-2">
            <form id="registrationForm">
                <div class="card">
                    <div class="card-body">

                        <!-- Step 1: Mobile Number Input with Fixed +91 -->
                        <div class="form-group basic" id="mobileSection">
                            <div class="input-wrapper">
                                <label class="label" for="mobile">Enter Mobile Number</label>
                                <div class="input-group">
                                    <span class="input-group-text">+91</span>
                                    <input type="tel" class="form-control" id="mobile" name="mobile" placeholder="Enter Mobile Number" maxlength="10" required>
                                </div>
                            </div>
                        </div>

                        <!-- Step 2: OTP Input with Separate Boxes for Each Digit -->
                        <div class="form-group basic" id="otpSection" style="display:none;">
                            <div class="input-wrapper">
                                <label class="label" for="otp">Enter OTP</label>
                                <div class="otp-container">
                                    <input type="text" class="otp-input" id="otp1" maxlength="1" required oninput="moveToNext(this, 'otp2')">
                                    <input type="text" class="otp-input" id="otp2" maxlength="1" required oninput="moveToNext(this, 'otp3')">
                                    <input type="text" class="otp-input" id="otp3" maxlength="1" required oninput="moveToNext(this, 'otp4')">
                                    <input type="text" class="otp-input" id="otp4" maxlength="1" required oninput="moveToNext(this, 'otp5')">
                                    <input type="text" class="otp-input" id="otp5" maxlength="1" required oninput="moveToNext(this, 'otp6')">
                                    <input type="text" class="otp-input" id="otp6" maxlength="1" required>
                                </div>
                                <div id="otpCountdown" style="padding-top: 5px;"></div>
                                <a href="#" id="resendLink" style="display:none;" onclick="resendOtp()">Resend OTP</a>
                            </div>
                        </div>

                    </div>
                </div>

                <!-- Button Group for Different Steps -->
                <div class="form-button-group transparent">
                    <button type="button" class="btn btn-primary btn-block btn-lg" id="sendOtpButton">Send OTP</button>
                </div>
            </form>

            <!-- ReCAPTCHA Widget -->
            <div id="recaptcha-container"></div>
        </div>
    </div>

    <script src="assets/js/lib/bootstrap.bundle.min.js"></script>
    <script src="https://www.gstatic.com/firebasejs/8.3.1/firebase-app.js"></script>
    <script src="https://www.gstatic.com/firebasejs/8.3.1/firebase-auth.js"></script>
    <script>
        var firebaseConfig = {
            apiKey: "AIzaSyCdP09prVY8cfEpXUwmwIxo8l9f7vWppv8",
            authDomain: "mlm-project-96d94.firebaseapp.com",
            projectId: "mlm-project-96d94",
            storageBucket: "mlm-project-96d94.appspot.com",
            messagingSenderId: "319115802196"
        };

        // Initialize Firebase
        firebase.initializeApp(firebaseConfig);
        const auth = firebase.auth();

        let countdownInterval;
        let recaptchaVerifier;

        // Initialize reCAPTCHA
        function initializeRecaptcha() {
            recaptchaVerifier = new firebase.auth.RecaptchaVerifier('recaptcha-container', {
                'size': 'invisible',
                'callback': (response) => {},
                'expired-callback': () => {}
            });
        }

        // Call this function to start reCAPTCHA verifier
        initializeRecaptcha();

        // Show OTP field and start countdown
        function showOtpField() {
            document.getElementById('mobileSection').style.display = 'none';
            document.getElementById('otpSection').style.display = 'block';
            startOtpCountdown(60);
            document.getElementById('sendOtpButton').style.display = 'none'; // Hide Send OTP button
        }

        // Start countdown timer
        function startOtpCountdown(duration) {
            let timer = duration, seconds;
            countdownInterval = setInterval(function () {
                seconds = parseInt(timer % 60, 10);
                document.getElementById('otpCountdown').innerHTML = "Resend OTP in " + seconds + " seconds";
                if (--timer < 0) {
                    clearInterval(countdownInterval);
                    document.getElementById('otpCountdown').innerHTML = "";
                    document.getElementById('resendLink').style.display = "block"; // Show resend link
                }
            }, 1000);
        }

        // Move to the next OTP input
        function moveToNext(currentInput, nextInputId) {
            if (currentInput.value.length >= 1) {
                document.getElementById(nextInputId).focus();
            }
        }

        // Handle OTP Resend
        function resendOtp() {
            const phoneNumber = document.getElementById('mobile').value;

            // Your logic to send OTP again
            console.log("Resending OTP to " + phoneNumber);

            // Firebase logic to resend OTP
            auth.signInWithPhoneNumber("+91" + phoneNumber, recaptchaVerifier)
                .then((confirmationResult) => {
                    window.confirmationResult = confirmationResult; // Store confirmationResult
                }).catch((error) => {
                    console.error("Error resending OTP: ", error);
                });
        }

        // Send OTP on button click
        document.getElementById('sendOtpButton').addEventListener('click', function () {
            const phoneNumber = document.getElementById('mobile').value;

            // Firebase logic to send OTP
            auth.signInWithPhoneNumber("+91" + phoneNumber, recaptchaVerifier)
                .then((confirmationResult) => {
                    window.confirmationResult = confirmationResult; // Store confirmationResult
                    showOtpField();
                }).catch((error) => {
                    console.error("Error sending OTP: ", error);
                });
        });

        // Verify OTP
        document.getElementById('otpSection').addEventListener('input', function () {
            let otp = "";
            for (let i = 1; i <= 6; i++) {
                otp += document.getElementById('otp' + i).value; // Concatenate OTP digits
            }

            // If all OTP digits are filled, proceed to verify
            if (otp.length === 6) {
                // Verify the OTP with Firebase
                window.confirmationResult.confirm(otp).then((result) => {
                    const user = result.user;
                    console.log("OTP verified successfully:", user);

                    // Redirect to register.php with mobile number as a query parameter
                    const mobile = document.getElementById('mobile').value;
                    window.location.href = "register.php?mobile=" + mobile;
                }).catch((error) => {
                    console.error("Error verifying OTP: ", error);
                    alert("Invalid OTP. Please try again.");
                });
            }
        });
    </script>
</body>

</html>
