<?php
session_start(); // Ensure session is started
include 'header.php';
include 'db.php';

// Initialize user_id variable (assuming it's retrieved from the session)
$user_id = $_SESSION['user_id'] ?? null; // Retrieve user_id from session or set to null

function getUserMyNumber($user_id) {
    global $conn;
    $sql = "SELECT `id`, `my_number`, `total_balance`, `phone` FROM `MLM_users` WHERE `id` = ?";
    $stmt = $conn->prepare($sql);
    
    if ($stmt) {
        $stmt->bind_param('i', $user_id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($row = $result->fetch_assoc()) {
            return $row; 
        } else {
            return null; 
        }
    } else {
        echo "Error preparing statement: " . $conn->error;
        return null;
    }
}

// Function to get user data recursively
function getUserData($reference_number, &$userCount)
{
    global $conn;

    // Limit the number of users to 120
    if ($userCount >= 120) {
        return [];
    }

    // Query to get the user data from refer_table
    $sql = "SELECT `id`, `new_code` AS `my_number`,`count` FROM `refer_table` WHERE `parent_code` = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('s', $reference_number);
    $stmt->execute();
    $result = $stmt->get_result();

    $children = [];
    while ($row = $result->fetch_assoc()) {
        // Prepare a new statement to get the total_balance from MLM_users
        $sql1 = "SELECT total_balance FROM MLM_users WHERE `my_number` = ?"; // Assuming you want `my_number`
        $stmt1 = $conn->prepare($sql1);
        $stmt1->bind_param('s', $row['my_number']); // Bind the correct `my_number`
        $stmt1->execute();
        $result1 = $stmt1->get_result();
        
        if ($balanceRow = $result1->fetch_assoc()) {
            $row['total_balance'] = $balanceRow['total_balance']; // Assign total_balance to row
        } else {
            $row['total_balance'] = null; // Handle if no balance is found
        }

        $stmt1->close(); // Close the second prepared statement

        $userCount++; // Increment user count
        if ($userCount >= 120) break; // Stop if count exceeds 120

        // Recursive call to get children
        $row['children'] = getUserData($row['my_number'], $userCount);

        $children[] = $row;
    }

    $stmt->close(); // Close the first prepared statement
    return $children;
}

$root_user_info = getUserMyNumber($user_id);
$root_my_number = $root_user_info['my_number'] ?? null;
$root_total_balance = $root_user_info['total_balance'] ?? null;

function getChildUsers($parent_code) {
    global $conn;
    $sql = "SELECT u.my_number, r.parent_code, r.new_code FROM MLM_users u
            JOIN refer_table r ON u.my_number = r.new_code
            WHERE r.parent_code = ? AND u.approved = 1";

    $stmt = $conn->prepare($sql);
    $stmt->bind_param('s', $parent_code);
    $stmt->execute();
    $result = $stmt->get_result();

    $children = [];
    while ($row = $result->fetch_assoc()) {
        $row['children'] = getChildUsers($row['new_code']);
        $children[] = $row; 
    }
    return $children;
}

// Fetch child users of the root user
$childUsers = [];
if ($root_my_number) {
    $childUsers = getChildUsers($root_my_number);
}

// Assign the child users to the tree data
$treeData = $childUsers;

// Close the database connection
$conn->close();
?>


<style>

    .scrollable-tree-container {
        overflow-x: auto;
        /* Enable horizontal scrolling */
        width: 100%;   
    justify-content: center;     
        display: flex;
    }

    .tree {
        display: flex;
        /* Use flexbox for horizontal layout */
    }

    .tree ul {
        display: flex;
        /* Use flexbox for inline list items */
        padding: 0;
        /* Remove padding for better alignment */
        margin: 0;
        /* Remove margin for better alignment */
        list-style: none;
        /* Remove bullets */
    }

    .tree li {
        float: left;
        text-align: center;
        list-style-type: none;
        position: relative;
        padding: 20px 5px 0 5px;
        transition: all 0.5s;
    }

    .tree li::before,
    .tree li::after {
        content: '';
        position: absolute;
        top: 0;
        right: 50%;
        border-top: 1px solid #ccc;
        width: 50%;
        height: 20px;
    }

    .tree li::after {
        right: auto;
        left: 50%;
        border-left: 1px solid #ccc;
    }

    .tree li:only-child::after,
    .tree li:only-child::before {
        display: none;
    }

    .tree li:only-child {
        padding-top: 0;
    }

    .tree li:first-child::before,
    .tree li:last-child::after {
        border: 0 none;
    }

    .tree li:last-child::before {
        border-right: 1px solid #ccc;
        border-radius: 0 5px 0 0;
    }

    .tree li:first-child::after {
        border-radius: 5px 0 0 0;
    }

    .tree ul ul::before {
        content: '';
        position: absolute;
        top: 0;
        left: 50%;
        border-left: 1px solid #ccc;
        width: 0;
        height: 20px;
    }

    .tree li a {
        border: 1px solid #ccc;
        padding: 5px 10px;
        text-decoration: none;
        color: #666;
        font-family: Arial, Verdana, Tahoma;
        font-size: 11px;
        display: inline-block;
        border-radius: 5px;
        transition: all 0.5s;
    }

    .tree li a:hover,
    .tree li a:hover+ul li a {
        background: #c8e4f8;
        color: #000;
        border: 1px solid #94a0b4;
    }

    .tree li a:hover+ul li::after,
    .tree li a:hover+ul li::before,
    .tree li a:hover+ul::before,
    .tree li a:hover+ul ul::before {
        border-color: #94a0b4;
    }

    .member-view-box {
        background: #f9f9f9;
        border: 1px solid #ccc;
        border-radius: 5px;
        padding: 10px;
        width: 150px;
        display: inline-block;
        cursor: pointer;
    }

    .member-image img {
        width: 30px;
        height: 30px;
        border-radius: 50%;
    }

    .member-text {
        font-size: 10px;
    }

    .highlight {
        background-color: #d1e7dd;
    }
</style>


<div id="appCapsule">

    <div class="section mb-5 p-2">

<div class="row gy-4" style="background-color: white; padding-bottom: 50px; overflow: auto; height: 400px;">
    <div class="col-lg-12">
        <div>
            <div class="scrollable-tree-container"> <!-- Set height for vertical scrolling -->
                <div class="tree" style="overflow: auto;" >
                    <style>
                        .member-image {
                            transition: transform 0.3s ease;
                        }
                        .member-image:hover {
                            transform: scale(1.2);
                        }
                    </style>

                    <?php
                    // Recursive function to display the tree, ensuring each node has exactly 4 users
                    function displayTree($data, $isRoot = false) {
                        if (empty($data)) {
                            return; // Exit if there's no data
                        }

                        echo '<ul>';
                        foreach ($data as $node) {
                            echo '<li>';

                            // Show user icon and text (active or deactive)
                            $iconColorStyle = empty($node['my_number']) ? '' : $node['my_number'];
                            $icon = empty($node['my_number']) ? '<div class="member-image" data-effect="zoom"><img src="assets/img/deactive.png" alt="User Icon"></div>' : '<div class="member-image" data-effect="zoom"><img src="assets/img/active.png" alt="User Icon"></div>';

                            $rootClass = $isRoot ? 'root-member' : 'root-member';
                            echo '<div class="' . $rootClass . '" data-id="' . htmlspecialchars($node['my_number']) . '" onclick="toggleChildren(this)">';
                            echo $icon;
                            echo '<div class="member-text">' . htmlspecialchars($iconColorStyle) . '</div>';
                            echo '</div>'; // Close member-view-box

                            // Fetch children or add placeholders to make total 4
                            $actualChildren = !empty($node['children']) ? $node['children'] : [];
                            $totalChildren = count($actualChildren);

                            // Display children initially hidden unless it's the root or immediate children
                            echo '<ul class="child-users" style="' . ($isRoot || $totalChildren > 0 ? 'display: block;' : 'display: none;') . '">';
                            foreach ($actualChildren as $child) {
                                displaySingleUser($child); // Display actual child
                            }

                            // If fewer than 4 children, add placeholders ("deactive" users)
                            for ($i = $totalChildren; $i < 4; $i++) {
                                echo '<li>';
                                echo '<div class="root-member" data-id="deactive">';
                                echo '<div class="member-image" data-effect="zoom"><img src="assets/img/deactive.png" alt="Deactivated User Icon"></div>';
                                echo '</div>';
                                echo '</li>';
                            }
                            echo '</ul>'; // Close child container
                            echo '</li>';
                        }
                        echo '</ul>';
                    }

                    // Helper function to display a single user and their children (if any)
                    function displaySingleUser($node) {
                        echo '<li>';
                        $icon = empty($node['my_number']) ? '<div class="member-image" data-effect="zoom"><img src="assets/img/deactive.png" alt="User Icon"></div>' : '<div class="member-image" data-effect="zoom"><img src="assets/img/active.png" alt="User Icon"></div>';
                        echo '<div class="root-member" data-id="' . htmlspecialchars($node['my_number']) . '" onclick="toggleChildren(this)">';
                        echo $icon;
                        echo '<div class="member-text">' . htmlspecialchars($node['my_number']) . '</div>';
                        echo '</div>';

                        // Ensure child users are displayed (if any), otherwise show placeholders
                        $actualChildren = !empty($node['children']) ? $node['children'] : [];
                        $totalChildren = count($actualChildren);

                        echo '<ul class="child-users" style="display:none;">'; // Keep all children hidden initially
                        foreach ($actualChildren as $child) {
                            displaySingleUser($child); // Recursive call for child nodes
                        }

                        // Add placeholders if fewer than 4 children
                        for ($i = $totalChildren; $i < 4; $i++) {
                            echo '<li>';
                            echo '<div class="root-member" data-id="deactive">';
                            echo '<div class="member-image" data-effect="zoom"><img src="assets/img/deactive.png" alt="Deactivated User Icon"></div>';
                            echo '<div class="member-text">Deactive</div>';
                            echo '</div>';
                            echo '</li>';
                        }
                        echo '</ul>'; // Close the children container
                        echo '</li>';
                    }

                    if ($root_my_number) {
                        $rootData = [
                            [
                                'my_number' => $root_my_number,
                                'reference_number' => '', 
                                'total_balance' => $root_total_balance, 
                                'children' => $treeData,
                            ]
                        ];
                        displayTree($rootData, true);
                    } else {
                        echo "<div>No user found.</div>"; 
                    }
                    ?>
                </div>
            </div>
        </div>
    </div>
</div>

</div></div>


    <script>
        document.querySelectorAll('.member-view-box').forEach(box => {
            box.addEventListener('click', function () {
                // Remove highlight from all boxes
                document.querySelectorAll('.member-view-box').forEach(b => {
                    b.classList.remove('highlight');
                });

                // Highlight the clicked box
                this.classList.add('highlight');

                // Optionally, handle other click actions here
                console.log("User ID:", this.getAttribute('data-id'));
            });
        });
        
        
    </script>


<script>
function toggleChildren(element) {
    const childContainer = element.nextElementSibling; // Get the next sibling (the UL containing children)
    
    // Close all siblings at the same level
    const siblings = element.parentElement.parentElement.children; // Get all siblings in the same UL
    for (let i = 0; i < siblings.length; i++) {
        const sibling = siblings[i].querySelector('.child-users');
        if (sibling && sibling !== childContainer) {
            sibling.style.display = 'none'; // Close other siblings' children
        }
    }

    // Toggle the display property of the clicked element's children
    if (childContainer) {
        if (childContainer.style.display === "none") {
            childContainer.style.display = "block"; // Open the clicked child's container
        } else {
            childContainer.style.display = "none"; // Close it if it's already open
        }
    }
}

</script>

    

</div>


<?php include 'footer.php'; ?>

