<?php
include 'db.php'; // Include the database connection file
session_start(); 

$mobileNumber = isset($_GET['mobile']) ? $_GET['mobile'] : null;

// Check if mobile number is provided
if ($mobileNumber) {
    $stmt = $conn->prepare("SELECT `id` FROM `MLM_users` WHERE `phone` = ?");
    $stmt->bind_param("s", $mobileNumber);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $stmt->bind_result($userId); // Bind the user ID to a variable
        $stmt->fetch(); // Fetch the user ID from the result
        $_SESSION['user_id'] = $userId; // Store user ID in session
        $_SESSION['mobile_number'] = $mobileNumber; // Store mobile number in session

        header("Location: index.php");
        exit();
    }

    $stmt->close();
} else {
    echo "Mobile number is required.";
    exit();
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $name = $_POST['name'];
    $phone = $_POST['mobile'];
    $reference = $_POST['reference'] ?? null;
    $tree_head = 0; 
    $total_balance = 0;
    $approved = 0;
    $my_number = ""; 

    // Insert into `user` table
    $stmt_user = $conn->prepare("INSERT INTO `user` (`u_name`, `u_phone`, `u_ref`, `created_date`) VALUES (?, ?, ?, NOW())");
    $stmt_user->bind_param("sss", $name, $phone, $reference);

    if ($stmt_user->execute()) {
        $userId = $stmt_user->insert_id;

        // Store user details in the session
        $_SESSION['user_id'] = $userId;
        $_SESSION['name'] = $name;
        $_SESSION['mobile_number'] = $mobileNumber;
        $_SESSION['reference'] = $reference;

        $stmt_mlm = $conn->prepare("INSERT INTO `MLM_users` (`u_id`, `name`, `phone`, `reference_number`, `tree_head`, `my_number`, `created_at`, `total_balance`, `approved`) 
                                    VALUES (?, ?, ?, ?, ?, ?, NOW(), ?, ?)");
        $stmt_mlm->bind_param("isssssis", $userId, $name, $phone, $reference, $tree_head, $my_number, $total_balance, $approved);

        if ($stmt_mlm->execute()) {
            $_SESSION['mlm_user_id'] = $stmt_mlm->insert_id; 

            header("Location: index.php");
            exit();
        } else {
            echo "Error inserting into the `MLM_users` table: " . $stmt_mlm->error;
        }

        $stmt_mlm->close();
    } else {
        echo "Error inserting into the `user` table: " . $stmt_user->error;
    }

    $stmt_user->close();
}
?>

<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1, viewport-fit=cover" />
    <title>Registration</title>
    <link rel="icon" type="image/png" href="assets/img/favicon.png" sizes="32x32">
    <link rel="stylesheet" href="assets/css/style.css">
</head>

<body>
    <div id="appCapsule">
        <div class="section mt-2 text-center">
            <h1>Complete Your Registration</h1>
            <h4>Welcome! Please fill in the details below.</h4>
        </div>

        <div class="section mb-5 p-2">
            <form id="registrationForm" action="" method="POST">
                <div class="card">
                    <div class="card-body">
                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label">Mobile Number</label>
                                <div class="input-prefix">
                                    <span>+91</span>
                                    <input type="tel" class="form-control" id="mobile" name="mobile" placeholder="Enter Mobile Number" value="<?php echo htmlspecialchars($mobileNumber); ?>" required >
                                </div>
                            </div>
                        </div>

                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label" for="name">Enter Your Name</label>
                                <input type="text" class="form-control" id="name" name="name" placeholder="Enter Your Name" required>
                            </div>
                        </div>

                        <div class="form-group basic">
                            <div class="input-wrapper">
                                <label class="label" for="reference">Reference Code (Optional)</label>
                                <input type="text" class="form-control" id="reference" name="reference" placeholder="Enter Reference Code">
                            </div>
                        </div>
                    </div>
                </div>

                <div class="form-button-group transparent">
                    <button type="submit" class="btn btn-primary btn-block btn-lg">Register</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        const urlParams = new URLSearchParams(window.location.search);
        const mobileNumber = urlParams.get('mobile');
        if (mobileNumber) {
            document.getElementById('mobile').value = mobileNumber.replace(/^(\+91)?/, ''); // Remove the +91 prefix if present
        }
    </script>
</body>
</html>
