<?php

session_start(); 

include 'db.php'; 
include 'header.php';

if (!isset($_SESSION['user_id'])) {
    echo "You are not logged in.";
    exit;
}

$userId = $_SESSION['user_id'];

// Query to fetch user details
$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number']; 
} else {
    echo "No user found with the provided ID.";
    exit;
}

// Function to fetch total amounts based on wallet type and optionally a date condition
function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";

    // Append date condition if provided
    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0; // Return total or 0 if null
}

function checkChilds($conn, $userId)
{
    $query = "SELECT COUNT(id) as total FROM refer_table WHERE parent_id = ? AND status = 1";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $userId);  // "i" for integer type
    $stmt->execute();
    $result = $stmt->get_result()->fetch_assoc();
    return $result['total'] ?? 0; // Return total or 0 if null
}


$checkparent = checkChilds($conn,$userId);
// Fetch balances and withdrawals
$userBalance = fetchTotalAmount($conn, $userId, 'add'); // Total balance
$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal'); // Total withdrawals
$userWithdraw = abs($userWithdraw); 
echo $userWithdraw;
// Calculate net balance
$netBalance = $userBalance - $userWithdraw; 

// Fetch today's balance and withdrawals
$todayCondition = 'AND DATE(created_at) = CURDATE()'; // Condition for today's date
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition); // Today's deposits
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition); // Today's withdrawals
$todayTotal = $todayBalance - $todayWithdraw;
// Fetch reference user's total balance
$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

// Fetch count of users who used the current user's reference number
$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

// Fetch count of users referred by the current user today
$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Pagination configuration
$limit = 5; // Number of transactions per page
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $limit;

// SQL query to fetch user's wallet transactions with pagination
$query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ? 
          ORDER BY `created_at` DESC 
          LIMIT ?, ?";

// Prepare and execute the statement
$stmt = $conn->prepare($query);
$stmt->bind_param("iii", $userId, $offset, $limit); 
$stmt->execute();
$result = $stmt->get_result(); 

// Fetch all transactions
$transactions = $result->fetch_all(MYSQLI_ASSOC); // Fetch associative array

// Get total number of transactions for pagination
$totalTransactionsQuery = "SELECT COUNT(*) as total FROM wallet_transactions WHERE user_id = ?";
$stmt = $conn->prepare($totalTransactionsQuery);
$stmt->bind_param("i", $userId);
$stmt->execute();
$totalTransactions = $stmt->get_result()->fetch_assoc()['total'];
$totalPages = ceil($totalTransactions / $limit);

?>

<!-- App Capsule -->
<div id="appCapsule">

    <!-- Wallet Card -->
    <div class="section wallet-card-section pt-1">
        <div class="wallet-card">
            <!-- Balance -->
            <div class="balance">
                <div class="left">
                    <span class="title">Total Balance</span>
                    <h1 class="total">₹<?php echo htmlspecialchars($netBalance) ?></h1>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            ₹ <?php echo htmlspecialchars($todayTotal); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                         &nbsp;Today
                    </p>
                </div>
                
                <div class="right">
                    <a href="#" class="button" data-bs-toggle="modal" data-bs-target="#withdrawalModal">
                        Withdraw
                    </a>
                </div>
            </div>
            <div class="balance">
            <div><?php if($checkparent != 4){?>
                 <span class="title">Freeze Balance</span>
                  <span class="bg-success-focus px-6 rounded-2 fw-medium text-success-main text-sm d-flex gap-8">
                            ₹ <?php echo htmlspecialchars($netBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        <span class="bg-success-focus px-6 rounded-2 fw-medium text-success-main text-xs d-flex gap-8">
                            to unfreeze balance complete your 4 member
                        </span>
                    <?php }else{ ?></div><div><?php } ?></div>
            </div>
        </div>
    </div>
    <!-- Wallet Card -->

    <div class="section mt-2">
        <div class="card" style="padding: 20px; margin-top: 20px; margin-bottom: 20px;">
            <div style="display: flex; align-items: center; flex-wrap: wrap; gap: 10px; justify-content: space-between; margin-bottom: 20px;">
                <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
                <div style="display: flex; gap: 10px;">
                    <input type="text" id="searchInput" class="form-control " placeholder="Search..." />
                    <select id="transactionFilter" class="form-select w-auto bg-base border text-secondary-light">
                        <option value="all">All</option>
                        <option value="add">Add</option>
                        <option value="withdrawal">Withdrawal</option>
                    </select>
                </div>
            </div>
<!-- Table content -->
<div class="table-responsive">
    <table class="table bordered-table mb-0">
        <thead>
            <tr>
                <th scope="col">S.L</th>
                <th scope="col">User ID</th>
                <th scope="col">Description (Transaction Type)</th>
                <th scope="col">Created At</th>
                <th scope="col">Amount</th>
                <th scope="col">Wallet Type</th>
            </tr>
        </thead>
        <tbody id="transactionTableBody">
            <?php if (empty($transactions)): ?>
                <tr>
                    <td colspan="6" class="text-center" style="color: #999;">
                        <strong>No wallet records found.</strong>
                    </td>
                </tr>
            <?php else: ?>
                <?php
                $counter = 1 + $offset; // Adjust the counter for pagination
                foreach ($transactions as $transaction) {
                    echo "<tr>";
                    echo "<td>{$counter}</td>";
                    echo "<td>{$transaction['user_id']}</td>";
                    echo "<td>{$transaction['description']}</td>";
                    echo "<td>{$transaction['created_at']}</td>";
                    echo "<td>₹" . number_format($transaction['amount'], 2) . "</td>";
                    echo "<td>
                            <span class='px-24 py-4 rounded-pill fw-medium text-sm " . 
                            ($transaction['wallet_type'] == 'add' ? 'bg-wallet-add text-wallet-add' : 'bg-wallet-withdrawal text-wallet-withdrawal') . "'>
                                " . ucfirst($transaction['wallet_type']) . "
                            </span>
                          </td>";
                    echo "</tr>";
                    $counter++;
                }
                ?>
            <?php endif; ?>
        </tbody>
    </table>
</div>
<div id="pagination" class="mt-3 d-flex justify-content-center">
    <?php
        $maxVisiblePages = 3;  // Number of pages to display
        $start = max(1, $page - floor($maxVisiblePages / 2));
        $end = min($totalPages, $start + $maxVisiblePages - 1);
        $start = max(1, $end - $maxVisiblePages + 1);  // Adjust start if necessary
    ?>

    <!-- Previous button (only show if not on the first page) -->
    <?php if ($page > 1): ?>
        <a href="?page=<?php echo max(1, $page-1); ?>" 
           style="width: 35px; height: 35px; display: flex; align-items: center; justify-content: center; margin: 0 5px; 
                  background-color: #ffffff; border-radius: 50%; color: #438fcd; text-decoration: none; border: 2px solid #438fcd;">
           &lt;
        </a>
    <?php endif; ?>

    <!-- Page numbers -->
    <?php for ($i = $start; $i <= $end; $i++): ?>
        <a href="?page=<?php echo $i; ?>" 
           class="<?php echo $i == $page ? 'active' : ''; ?>" 
           style="width: 35px; height: 35px; display: flex; align-items: center; justify-content: center; margin: 0 5px; 
                  border-radius: 50%; text-decoration: none; 
                  background-color: <?php echo $i == $page ? '#438fcd' : '#ffffff'; ?>; 
                  color: <?php echo $i == $page ? '#fff' : '#438fcd'; ?>; 
                  border: 2px solid #438fcd;">
           <?php echo $i; ?>
        </a>
    <?php endfor; ?>

    <!-- Next button (only show if not on the last page) -->
    <?php if ($page < $totalPages): ?>
        <a href="?page=<?php echo min($totalPages, $page+1); ?>" 
           style="width: 35px; height: 35px; display: flex; align-items: center; justify-content: center; margin: 0 5px; 
                  background-color: #ffffff; border-radius: 50%; color: #438fcd; text-decoration: none; border: 2px solid #438fcd;">
           &gt;
        </a>
    <?php endif; ?>
</div>

        </div>
    </div>

</div>



<script>
    function validateWithdrawal() {
        const withdrawalAmount = parseFloat(document.getElementById('withdrawalAmount').value);
        const netBalance = parseFloat(<?php echo htmlspecialchars($userBalance); ?>); // Ensure you pass the user's balance from PHP
        const bankNumber = document.getElementById('bankNumber').value;

        // Define the minimum balance that must remain after withdrawal
        const minimumBalance = 200;

        // Clear any previous error messages
        const errorMessageElement = document.getElementById('error-message');
        errorMessageElement.style.display = 'none';
        errorMessageElement.innerText = '';

        const bankNumberErrorElement = document.getElementById('bankNumberError');
        bankNumberErrorElement.style.display = 'none';
        bankNumberErrorElement.innerText = '';

        // Check if the user has 200 or less balance
        if (netBalance <= minimumBalance) {
            errorMessageElement.innerText = 'Your balance must be above ₹200.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the withdrawal amount is less than 100
        if (withdrawalAmount < 100) {
            errorMessageElement.innerText = 'Minimum withdrawal: ₹100.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }
        
        // Check if the withdrawal amount exceeds the available balance minus the minimum balance requirement
        if (withdrawalAmount > (netBalance - minimumBalance)) {
            errorMessageElement.innerText = 'You can only withdraw up to ₹' + (netBalance - minimumBalance) + '.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the bank number is valid
        const bankNumberPattern = /^\d{1,16}$/;
        if (!bankNumberPattern.test(bankNumber)) {
            bankNumberErrorElement.innerText = 'Bank number must be 1 to 16 digits long and contain only numbers.';
            bankNumberErrorElement.style.display = 'block';
            return false; // Prevent form submission
        }

        return true; // Allow form submission if all validations pass
    }
</script>


<script>
    document.addEventListener('DOMContentLoaded', function () {
        const searchInput = document.getElementById('searchInput');
        const transactionFilter = document.getElementById('transactionFilter');
        const transactionTableBody = document.getElementById('transactionTableBody');
        const rows = transactionTableBody.getElementsByTagName('tr');

        // Filter function for search and wallet type
        function filterTransactions() {
            const searchTerm = searchInput.value.toLowerCase();
            const selectedType = transactionFilter.value;
            Array.from(rows).forEach(row => {
                const cells = row.getElementsByTagName('td');
                const description = cells[2].textContent.toLowerCase();
                const walletType = cells[5].textContent.toLowerCase();
                const matchSearch = description.includes(searchTerm);
                const matchType = selectedType === 'all' || walletType.includes(selectedType);
                row.style.display = matchSearch && matchType ? '' : 'none';
            });
        }

        searchInput.addEventListener('input', filterTransactions);
        transactionFilter.addEventListener('change', filterTransactions);
    });
</script>

<?php include 'footer.php'; ?>
<?php include 'process_withdrawal.php'; ?>

