<?php
session_start();
include 'db.php'; 
include 'header.php';

if (!isset($_SESSION['mlm_user_id'])) {
    echo "You are not logged in.";
    exit;
}

$userId = $_SESSION['mlm_user_id'];

$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number']; 
} else {
    echo "No user found with the provided ID.";
    exit;
}

function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";
    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0; 
}

$userBalance = fetchTotalAmount($conn, $userId, 'add');
$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal');
$userWithdraw = abs($userWithdraw); // Convert withdrawals to positive if needed
$netBalance = $userBalance - $userWithdraw; // Correctly calculate net balance

$todayCondition = 'AND DATE(created_at) = CURDATE()'; // Condition for today's date
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition); // Today's deposits
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition); // Today's withdrawals

$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;

// Pagination configuration
$limit = 10; // Number of transactions per page
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $limit;

// SQL query to fetch user's wallet transactions with pagination
$query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ? 
          ORDER BY `created_at` DESC 
          LIMIT ?, ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("iii", $userId, $offset, $limit); 
$stmt->execute();
$result = $stmt->get_result(); 
$transactions = $result->fetch_all(MYSQLI_ASSOC); // Fetch associative array

// Get total number of transactions for pagination
$totalTransactionsQuery = "SELECT COUNT(*) as total FROM wallet_transactions WHERE user_id = ?";
$stmt = $conn->prepare($totalTransactionsQuery);
$stmt->bind_param("i", $userId);
$stmt->execute();
$totalTransactions = $stmt->get_result()->fetch_assoc()['total'];
$totalPages = ceil($totalTransactions / $limit);

// Withdrawal logic
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $amount = $_POST['withdrawalAmount'];

    // Query to get the user's total balance
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = 'add'";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    $userBalance = $result->fetch_assoc()['total'] ?? 0;

    // Check if the withdrawal conditions are met
    if ($amount <= $userBalance - 200 && $amount >= 100) {
        $withdrawalQuery = "INSERT INTO wallet_transactions (user_id, amount, description, created_at, wallet_type) VALUES (?, ?, ?, NOW(), 'withdrawal')";
        $description = "Withdrawal of ₹" . $amount;
        $stmt = $conn->prepare($withdrawalQuery);
        $stmt->bind_param("ids", $userId, $amount, $description);

        if ($stmt->execute()) {
            echo "<script>alert('Withdrawal successful!'); window.location.href = 'wallet.php';</script>";
        } else {
            echo "<script>alert('Error processing withdrawal. Please try again.'); window.location.href = 'wallet.php';</script>";
        }
    } else {
        echo "<script>alert('Insufficient balance or invalid amount. Minimum withdrawal: ₹100. Retain at least ₹200 in your balance.'); window.location.href = 'wallet.php';</script>";
    }
}
?>

<!-- App Capsule -->
<div id="appCapsule">
    <!-- Wallet Card -->
    <div class="section wallet-card-section pt-1">
        <div class="wallet-card">
            <!-- Balance -->
            <div class="balance">
                <div class="left">
                    <span class="title">Total Balance</span>
                    <h1 class="total">₹<?php echo htmlspecialchars($netBalance); ?></h1>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            ₹ <?php echo htmlspecialchars($todayBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        Today
                    </p>
                </div>
                <div class="right">
                    <a href="#" class="button" data-bs-toggle="modal" data-bs-target="#withdrawalModal">
                        <ion-icon name="add-outline"></ion-icon>
                    </a>
                </div>
            </div>
        </div>
    </div>
    <!-- Wallet Card -->

    <div class="section mt-2">
        <div class="card" style="padding: 20px; margin-top: 20px; margin-bottom: 20px;">
            <div style="display: flex; align-items: center; flex-wrap: wrap; gap: 10px; justify-content: space-between; margin-bottom: 20px;">
                <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
                <div style="display: flex; gap: 10px;">
                    <input type="text" id="searchInput" class="form-control form-control-sm w-auto" placeholder="Search..." />
                    <select id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                        <option value="all">All</option>
                        <option value="add">Add</option>
                        <option value="withdrawal">Withdrawal</option>
                    </select>
                </div>
            </div>
            <div class="table-responsive">
                <table class="table bordered-table mb-0">
                    <thead>
                        <tr>
                            <th scope="col">S.L</th>
                            <th scope="col">User ID</th>
                            <th scope="col">Description (Transaction Type)</th>
                            <th scope="col">Created At</th>
                            <th scope="col">Amount</th>
                            <th scope="col">Wallet Type</th>
                        </tr>
                    </thead>
                    <tbody id="transactionTableBody">
                        <?php
                        $counter = 1 + $offset; // Adjust the counter for pagination
                        foreach ($transactions as $transaction) {
                            echo "<tr>";
                            echo "<td>{$counter}</td>";
                            echo "<td>{$transaction['user_id']}</td>";
                            echo "<td>{$transaction['description']}</td>";
                            echo "<td>{$transaction['created_at']}</td>";
                            echo "<td>₹" . number_format($transaction['amount'], 2) . "</td>";
                            echo "<td>
                                    <span class='px-24 py-4 rounded-pill fw-medium text-sm " . 
                                    ($transaction['wallet_type'] == 'add' ? 'bg-wallet-add text-wallet-add' : 'bg-wallet-withdrawal text-wallet-withdrawal') . "'>
                                        " . ucfirst($transaction['wallet_type']) . "
                                    </span>
                                  </td>";
                            echo "</tr>";
                            $counter++;
                        }
                        ?>
                    </tbody>
                </table>
            </div>
            <!-- Pagination -->
            <nav aria-label="Page navigation">
                <ul class="pagination">
                    <?php for ($i = 1; $i <= $totalPages; $i++) : ?>
                        <li class="page-item <?php echo ($page == $i) ? 'active' : ''; ?>">
                            <a class="page-link" href="?page=<?php echo $i; ?>"><?php echo $i; ?></a>
                        </li>
                    <?php endfor; ?>
                </ul>
            </nav>
            <!-- End Pagination -->
        </div>
    </div>



<?php include 'footer.php'; ?>


<!-- Withdrawal Modal -->
<div class="modal fade" id="withdrawalModal" tabindex="-1" aria-labelledby="withdrawalModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="withdrawalModalLabel">Withdrawal Details</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="withdrawalForm" method="POST" onsubmit="return validateWithdrawal();">
                    <div class="mb-3">
                        <label for="userName" class="form-label">User Name *</label>
                        <input type="text" class="form-control" id="userName" name="user_name" required>
                    </div>
                    <div class="mb-3">
                        <label for="bankName" class="form-label">Bank Name *</label>
                        <input type="text" class="form-control" id="bankName" name="bank_name" required>
                    </div>
                    <div class="mb-3">
                        <label for="bankNumber" class="form-label">Bank Number *</label>
                        <input type="text" class="form-control" id="bankNumber" name="bank_number" pattern="\d{1,16}" maxlength="16" title="Only digits are allowed. Maximum 16 digits." required>
                        <div id="bankNumberError" class="text-danger" style="display: none;"></div>
                    </div>
                    <div class="mb-3">
                        <label for="branch" class="form-label">Branch *</label>
                        <input type="text" class="form-control" id="branch" name="branch" required>
                    </div>
                    <div class="mb-3">
                        <label for="withdrawalAmount" class="form-label">Withdrawal Amount *</label>
                        <div id="error-message" class="text-danger" style="display: none;"></div>
                        <input type="number" class="form-control" id="withdrawalAmount" name="withdrawal_amount" step="0.01" required>
                    </div>
                    <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($userId); ?>">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary" form="withdrawalForm">Withdraw</button>
            </div>
        </div>
    </div>
</div>


<script>
    function validateWithdrawal() {
        const withdrawalAmount = parseFloat(document.getElementById('withdrawalAmount').value);
        const netBalance = parseFloat(<?php echo htmlspecialchars($userBalance); ?>); // Ensure you pass the user's balance from PHP
        const bankNumber = document.getElementById('bankNumber').value;

        // Define the minimum balance that must remain after withdrawal
        const minimumBalance = 200;

        // Clear any previous error messages
        const errorMessageElement = document.getElementById('error-message');
        errorMessageElement.style.display = 'none';
        errorMessageElement.innerText = '';

        const bankNumberErrorElement = document.getElementById('bankNumberError');
        bankNumberErrorElement.style.display = 'none';
        bankNumberErrorElement.innerText = '';

        // Check if the user has 200 or less balance
        if (netBalance <= minimumBalance) {
            errorMessageElement.innerText = 'Your balance must be above ₹200.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the withdrawal amount is less than 100
        if (withdrawalAmount < 100) {
            errorMessageElement.innerText = 'Minimum withdrawal: ₹100.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }
        
        // Check if the withdrawal amount exceeds the available balance minus the minimum balance requirement
        if (withdrawalAmount > (netBalance - minimumBalance)) {
            errorMessageElement.innerText = 'You can only withdraw up to ₹' + (netBalance - minimumBalance) + '.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the bank number is valid
        const bankNumberPattern = /^\d{1,16}$/;
        if (!bankNumberPattern.test(bankNumber)) {
            bankNumberErrorElement.innerText = 'Bank number must be 1 to 16 digits long and contain only numbers.';
            bankNumberErrorElement.style.display = 'block';
            return false; // Prevent form submission
        }

        return true; // Allow form submission if all validations pass
    }
</script>
