<?php
session_start(); 

include 'db.php'; 
include 'header.php';

if (!isset($_SESSION['user_id'])) {
    echo "You are not logged in.";
    exit;
}

$userId = $_SESSION['user_id'];

// Echo the user ID for debugging purposes
echo "User ID: " . htmlspecialchars($userId) . "<br>"; 

// Initialize variables for filtering
$filterType = isset($_POST['transactionType']) ? $_POST['transactionType'] : 'all';
$searchTerm = isset($_POST['searchTerm']) ? $_POST['searchTerm'] : '';

// Build the SQL query based on filters
$query = "SELECT `id`, `user_id`, `user_name`, `bank_name`, `bank_number`, `withdrawal_amount`, `branch`, `type`, `created_at` 
          FROM `payment_withdrawals` 
          WHERE `user_id` = ?"; // Filter by user ID

if ($filterType !== 'all') {
    $query .= " AND `type` = ?";
}

if (!empty($searchTerm)) {
    $searchTerm = "%$searchTerm%"; // Prepare the search term for LIKE
    $query .= " AND (`user_name` LIKE ? OR `bank_name` LIKE ? OR `created_at` LIKE ?)";
}

// Prepare the statement
$stmt = $conn->prepare($query);

// Bind parameters
if ($filterType !== 'all') {
    if (!empty($searchTerm)) {
        $stmt->bind_param("ssss", $userId, $filterType, $searchTerm, $searchTerm);
    } else {
        $stmt->bind_param("ss", $userId, $filterType);
    }
} else {
    if (!empty($searchTerm)) {
        $stmt->bind_param("sss", $userId, $searchTerm, $searchTerm);
    } else {
        $stmt->bind_param("s", $userId);
    }
}

// Execute the query
$stmt->execute();
$result = $stmt->get_result();
?>

<div class="section mt-2">
    <div class="card" style="padding: 20px; margin-top: 80px; margin-bottom: 20px;">
        <div style="display: flex; align-items: center; flex-wrap: wrap; gap: 10px; justify-content: space-between; margin-bottom: 20px;">
            <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
            <form id="filterForm" method="post">
                <div style="display: flex; gap: 10px;">
                    <input type="text" id="searchInput" name="searchTerm" class="form-control form-control-sm w-auto" placeholder="Search..." 
                        value="<?php echo htmlspecialchars(trim(str_replace('%', '', $searchTerm))); ?>" 
                        oninput="checkInputLength();" />
                    <select id="transactionFilter" name="transactionType" class="form-select form-select-sm w-auto bg-base border text-secondary-light" 
                        onchange="document.getElementById('filterForm').submit();">
                        <option value="all" <?php echo ($filterType === 'all') ? 'selected' : ''; ?>>All</option>
                        <option value="add" <?php echo ($filterType === 'add') ? 'selected' : ''; ?>>Add</option>
                        <option value="withdrawal" <?php echo ($filterType === 'withdrawal') ? 'selected' : ''; ?>>Withdrawal</option>
                        <option value="pending" <?php echo ($filterType === 'pending') ? 'selected' : ''; ?>>Pending</option>
                    </select>
                </div>
            </form>
        </div>
        <div class="table-responsive">
            <table class="table">
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">User ID</th>
                        <th scope="col">User Name</th>
                        <th scope="col">Bank Name</th>
                        <th scope="col">Bank Number</th>
                        <th scope="col">Withdrawal Amount</th>
                        <th scope="col">Branch</th>
                        <th scope="col">Created At</th>
                        <th scope="col">Type</th>
                    </tr>
                </thead>
                <tbody id="transactionTableBody">
                    <?php
                    // Initialize serial number counter
                    $sl = 1;

                    // Check if there are any results
                    if ($result->num_rows > 0) {
                        // Loop through each row and display it
                        while ($row = $result->fetch_assoc()) {
                            // Determine classes for the wallet type
                            $wallet_type_class = '';
                            $wallet_type_text_class = '';

                            if ($row['type'] == 'add') {
                                $wallet_type_class = 'bg-wallet-add';
                                $wallet_type_text_class = 'text-wallet-add';
                            } elseif ($row['type'] == 'withdrawal') {
                                $wallet_type_class = 'bg-wallet-withdrawal';
                                $wallet_type_text_class = 'text-wallet-withdrawal';
                            } elseif ($row['type'] == 'pending') {
                                $wallet_type_class = 'bg-wallet-pending';
                                $wallet_type_text_class = 'text-wallet-pending';
                            }

                            echo "<tr>
                                    <td>{$sl}</td>
                                    <td>{$row['user_id']}</td>
                                    <td>{$row['user_name']}</td>
                                    <td>{$row['bank_name']}</td>
                                    <td>{$row['bank_number']}</td>
                                    <td>₹{$row['withdrawal_amount']}</td>
                                    <td>{$row['branch']}</td>
                                    <td>{$row['created_at']}</td>
                                    <td>
                                        <span class='px-24 py-4 rounded-pill fw-medium text-sm {$wallet_type_class} {$wallet_type_text_class}'>
                                            " . ucfirst($row['type']) . "
                                        </span>
                                    </td>
                                  </tr>";
                            $sl++;
                        }
                    } else {
                        echo "<tr><td colspan='9' class='text-center text-muted'>No transaction history found.</td></tr>";
                    }

                    // Close the statement and connection
                    $stmt->close();
                    $conn->close();
                    ?>
                </tbody>
            </table>
        </div>
        <div id="pagination" class="mt-3 d-flex justify-content-center"></div>

    </div>
    <?php 
    ?>
</div>

<script>
let timeout = null; // Variable to hold the timeout

function checkInputLength() {
    clearTimeout(timeout); // Clear the previous timeout

    // Get the input element
    var inputElement = document.getElementById('searchInput');

    // Set a timeout to submit the form after 500 milliseconds of inactivity
    timeout = setTimeout(function() {
        // Get the input value and remove % characters
        var input = inputElement.value.replace(/%/g, ''); // Corrected to replace % characters

        // Update the input value without % characters
        inputElement.value = input;

        // Submit the form only if the input length is greater than or equal to 2
        if (input.length >= 2) {
            document.getElementById('filterForm').submit();
        }
    }, 500); // Delay of 500 milliseconds
}
</script>

<?php include 'footer.php'; ?>

<!-- Styles for Add, Withdrawal, and Pending Statuses -->
<style>
    .text-wallet-add {
        color: #4CAF50 !important; /* Green text color */
    }

    .text-wallet-withdrawal {
        color: #F44336 !important; /* Red text color */
    }

    .text-wallet-pending {
        color: #FFA500 !important; /* Orange text color for pending */
    }

    /* Scrollable table style */
    .table-responsive {
        max-height: 400px; /* Set your desired height */
        overflow-y: auto; /* Enable vertical scrolling */
    }
</style>
