<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);
session_start();

if (!isset($_SESSION['id'])) {
    header("Location: index.php");
    exit;
}

include 'db.php';


$admin_id = $_SESSION['id'];
$query = "SELECT admin_type FROM admin WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $admin_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $admin_type = $row['admin_type']; // Store admin_type in a variable
} else {
    $admin_type = null; // Default if not found
}

// Initialize user_type
$user_type = isset($_POST['user_type']) ? $_POST['user_type'] : 'all'; // Default to 'all'

// Prepare the SQL query based on the selected user type
if ($user_type == 'direct_join') {
    $user_stmt = $conn->prepare("SELECT id, name, phone, reference_number,tree_head, my_number, created_at, total_balance, approved FROM MLM_users WHERE reference_number IS NULL");
} elseif ($user_type == 'reference_user') {
    $user_stmt = $conn->prepare("SELECT id, name, phone, reference_number,tree_head, my_number, created_at, total_balance, approved FROM MLM_users WHERE reference_number IS NOT NULL");
} else {
    // Default case for All Users
    $user_stmt = $conn->prepare("SELECT id, name, phone, reference_number,tree_head, my_number, created_at, total_balance, approved FROM MLM_users");
}

// Execute the query
$user_stmt->execute();
$user_result = $user_stmt->get_result();

// Fetch all users
$users = $user_result->fetch_all(MYSQLI_ASSOC);
$user_stmt->close();

// Function to log errors (Optional, can be used as needed)
function logError($message)
{
    error_log($message, 3, "error_log.log");
}





// Function to check if the user is authorized
function isAuthorized($conn, $user_id)
{
    $stmt = $conn->prepare("SELECT admin_type FROM admin WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($admin_type);
    $stmt->fetch();
    $stmt->close();

    return $admin_type == 1;
}

// Function to insert wallet transaction
function insertWalletTransaction($conn, $user_id, $amount, $description, $child)
{
    $stmt = $conn->prepare("INSERT INTO wallet_transactions (user_id, child, amount, description, created_at, wallet_type) VALUES (?, ?, ?, ?, NOW(), 'add')");
    
    // Corrected bind_param types: "ii" for user_id and child, "d" for amount (double), "s" for description (string)
    $stmt->bind_param("iids", $user_id, $child, $amount, $description);

    if (!$stmt->execute()) {
        logError("Failed to insert transaction for user ID $user_id: " . $stmt->error);
    }

    $stmt->close();
}

function generatecode($length = 6) {
    $characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYabcdefghijklmnopqrstuvwxyzZ0123456789';
    $code = '';
    
    for ($i = 0; $i < $length; $i++) {
        $index = rand(0, strlen($characters) - 1);
        $code .= $characters[$index];
    }
    
    return $code;
}

// Function to generate a unique my_number
function generateMyNumber($conn)
{
    do {
        $random_number = generatecode();
        $my_number = $random_number;

        // Check for uniqueness
        $stmt = $conn->prepare("SELECT COUNT(*) FROM MLM_users WHERE my_number = ?");
        $stmt->bind_param("s", $my_number);
        $stmt->execute();
        $stmt->bind_result($count);
        $stmt->fetch();
        $stmt->close();
    } while ($count > 0);

    return $my_number;
}






// Function to distribute bonuses
function distributeBonuses($conn, $my_number, $reference_number, $tree_head, $user_id)
{
    $bonus_amount_25 = 200 * 0.25; // 25% of 200
    $bonus_amount_5 = 200 * 0.05;  // 5% of 200

    // Fetch the reference user who will receive the 25% bonus
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $reference_number);
    $stmt->execute();
    $reference_result = $stmt->get_result();
    
    // Fetch the ID of the user initiating the bonus distribution
    $stmt1 = $conn->prepare("SELECT id,name,my_number FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt1->bind_param("s", $my_number);
    $stmt1->execute();
    $user_result = $stmt1->get_result();
    $user_data = $user_result->fetch_assoc();
    $initiating_user_id = $user_data['id'];
    $username = $user_data['name'];
    $five_number = $user_data['my_number'];

    while ($reference_user = $reference_result->fetch_assoc()) {
        $reference_user_id = $reference_user['id'];

        // Update balance with 25% bonus
        $update_balance_stmt_25 = $conn->prepare("UPDATE MLM_users SET total_balance = total_balance + ? WHERE id = ?");
        $update_balance_stmt_25->bind_param("di", $bonus_amount_25, $reference_user_id);
        $update_balance_stmt_25->execute();
        $update_balance_stmt_25->close();

        // Log the 25% bonus transaction
        insertWalletTransaction($conn, $reference_user_id, $bonus_amount_25, "25% Direct bonus for referring $username", $initiating_user_id);

        // Start the recursive 5% bonus distribution
        distributeFivePercentBonus($conn, $reference_user_id, $bonus_amount_5, $initiating_user_id,$five_number);
    }
}

function distributeFivePercentBonus($conn, $user_id, $bonus_amount_5, $initiating_user_id,$five_number) {
    // Fetch the reference number for the current user
    $stmt = $conn->prepare("SELECT reference_number FROM MLM_users WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($reference_number);
    $stmt->fetch();
    $stmt->close();

    // Stop if no reference_number is found
    if (empty($reference_number)) {
        return;
    }

    // Fetch the user who matches the reference number
    $stmt = $conn->prepare("SELECT id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $reference_number);
    $stmt->execute();
    $reference_result = $stmt->get_result();

    while ($bonus_user = $reference_result->fetch_assoc()) {
        $bonus_user_id = $bonus_user['id'];

        // Update balance for the 5% bonus
        $update_balance_stmt_5 = $conn->prepare("UPDATE MLM_users SET total_balance = total_balance + ? WHERE id = ?");
        $update_balance_stmt_5->bind_param("di", $bonus_amount_5, $bonus_user_id);
        $update_balance_stmt_5->execute();
        $update_balance_stmt_5->close();

        // Log the 5% bonus transaction
        insertWalletTransaction($conn, $bonus_user_id, $bonus_amount_5, "5% bonus for the referral of $five_number", $initiating_user_id);

        // Recursive call for further distribution
        distributeFivePercentBonus($conn, $bonus_user_id, $bonus_amount_5, $initiating_user_id,$five_number);
    }
}


function getTreeNode($conn, $referral_code)
{
    // Prepare query to fetch reference number and id from MLM_users
    $stmt = $conn->prepare("SELECT reference_number, id FROM MLM_users WHERE my_number = ? AND approved = 1");
    $stmt->bind_param("s", $referral_code);
    $stmt->execute();
    $result = $stmt->get_result(); // Fetch result

    // If a result is found, proceed
    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        $ab = $row['reference_number']; // Tree head (reference number)
        $thid = $row['id']; // Tree head ID
        $stmt->close(); // Close the first statement

        // Prepare query to fetch new_code from refer_table
        // $stmt1 = $conn->prepare("SELECT new_code FROM refer_table WHERE parent_code = ? AND status = 1 AND count != 4 LIMIT 1");
        $stmt1 = $conn->prepare("SELECT new_code FROM refer_table WHERE parent_code = ?  AND status = 1 AND count != 4 LIMIT 1");
        $stmt1->bind_param("s", $referral_code);
        $stmt1->execute();
        $result1 = $stmt1->get_result(); // Fetch result for the second query

        // If new_code is found, return tree_head, selected_node, and tree_head_id
        if ($result1->num_rows > 0) {
            $row1 = $result1->fetch_assoc();
            $stmt1->close();
            return [
                'tree_head' => $ab,
                'selected_node' => $row1['new_code'],
                'tree_head_id' => $thid
            ];
        } else {
            // If no selected_node is found, return tree_head and tree_head_id without selected_node
            $stmt1->close();
            return [
                'tree_head' => $ab,
                'selected_node' => null, // No selected node found
                'tree_head_id' => $thid
            ];
        }
    } else {
        // No data found for the given referral code
        $stmt->close();
        return null;
    }
}



function approveUser($conn, $user_id, $referral_code) {
    // Set default referral_code if empty
    $referral_code = setDefaultReferralCode($referral_code);

    // Fetch user details
    $userDetails = getUserDetails($conn, $user_id);
    $my_number = $userDetails['my_number'];
    $reference_number = $userDetails['reference_number'];

    // Generate my_number if not available
    if (empty($my_number)) {
        $my_number = generateMyNumber($conn);
    }

    // Update reference_number if empty
    if (empty($reference_number)) {
        $reference_number = fetchBlankNode($conn, $user_id);
        updateReferenceNumber($conn, $user_id, $reference_number);
    }

    // Fetch tree_head
    $tree_head = getTreeHead($conn, $referral_code);

    // Update user approval status, tree_head, and my_number
    if (updateUserApproval($conn, $user_id, $tree_head, $my_number)) {
        
        // Insert into refer_table if referral code does not exist
        if (!checkReferralCodeExists($conn, $my_number)) {
            insertReferTableRecords($conn, $my_number, 4);
        }

        // Update refer_table with new_id and new_code
        $message = updateReferTable($conn, $user_id, $my_number, $reference_number);
    } else {
        $message = 'Failed to update MLM_users.';
    }
    header("Location: users-list.php");
  

    return $message; // Return the final message
      exit();
}


// Helper function to set default referral code
function setDefaultReferralCode($referral_code)
{
    return empty($referral_code) ? "default" : $referral_code;
}

function fetchBlankNode($conn, $user_id) {
    $stmt = $conn->prepare("SELECT parent_code FROM refer_table WHERE status = 0 AND new_code = ? LIMIT 1");
    $blank_code = ""; // Placeholder for empty string
    $stmt->bind_param("s", $blank_code);
    
    if ($stmt->execute()) {
        $stmt->bind_result($parent_code);
        if ($stmt->fetch()) {
            $stmt->close();
            return $parent_code; // Return the fetched code if successful
        }
    }
    
    $stmt->close();
    return null; // Return null if no result was found
}

// Fetch user details
function getUserDetails($conn, $user_id)
{
    $stmt = $conn->prepare("SELECT my_number, reference_number FROM MLM_users WHERE id = ?");
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $stmt->bind_result($my_number, $reference_number);
    $stmt->fetch();
    $stmt->close();

    return ['my_number' => $my_number, 'reference_number' => $reference_number];
}

// Update reference number
function updateReferenceNumber($conn, $user_id, $reference_number)
{
    $stmt = $conn->prepare("UPDATE MLM_users SET reference_number = ? WHERE id = ?");
    $stmt->bind_param("si", $reference_number, $user_id);
    $stmt->execute();
    $stmt->close();
}

// Fetch tree_head from refer_table
function getTreeHead($conn, $referral_code)
{
    $stmt = $conn->prepare("SELECT parent_code AS tree_head FROM refer_table WHERE new_code = ?");
    $stmt->bind_param("s", $referral_code);
    $stmt->execute();
    $stmt->bind_result($tree_head);
    $tree_head = $stmt->fetch() ? $tree_head : "0"; // Default to 0 if no tree_head is found
    $stmt->close();

    return $tree_head;
}

// Update user approval status, tree_head, and my_number
function updateUserApproval($conn, $user_id, $tree_head, $my_number)
{
    $stmt = $conn->prepare("UPDATE MLM_users SET approved = 1, tree_head = ?, my_number = ? WHERE id = ?");
    $stmt->bind_param("ssi", $tree_head, $my_number, $user_id);
    $result = $stmt->execute();
    $stmt->close();
    return $result;
}

// Check if referral code exists in refer_table
function checkReferralCodeExists($conn, $my_number)
{
    $stmt = $conn->prepare("SELECT COUNT(*) FROM refer_table WHERE parent_code = ?");
    $stmt->bind_param("s", $my_number);
    $stmt->execute();
    $stmt->bind_result($exists);
    $stmt->fetch();
    $stmt->close();

    return $exists > 0;
}

// Insert records into refer_table
function insertReferTableRecords($conn, $my_number, $count)
{
    for ($i = 0; $i < $count; $i++) {
        $stmt = $conn->prepare("INSERT INTO refer_table (parent_code) VALUES (?)");
        $stmt->bind_param("s", $my_number);
        if (!$stmt->execute()) {
            throw new Exception('Failed to insert into refer_table: ' . $stmt->error);
        }
        $stmt->close();
    }
}

function updateReferTable($conn, $user_id, $my_number, $referral_code)
{
    // Get the tree node based on the referral code
    $node = getTreeNode($conn, $referral_code);
   
    $parent_id = 0; // Avoids passing a literal value directly
    
    $stmt = $conn->prepare("UPDATE refer_table SET new_id = ?, new_code = ?, status = 1, parent_id = ?, refer_code = ?, tree_head_code = ?, tree_head_id = ? WHERE parent_code = ? AND count != 4 AND status = 'false' LIMIT 1");
    $stmt->bind_param("isissis", $user_id, $my_number, $node['tree_head_id'], $referral_code, $node['tree_head'], $node['tree_head_id'], $referral_code);
    $stmt->execute();

    // If no rows were affected, attempt to update using selected_node
    if ($stmt->affected_rows == 0) {
        $stmt->close(); // Close the previous statement

        $refer_code = !empty($node['selected_node']) ? $node['selected_node'] : $referral_code;

        $stmt = $conn->prepare("UPDATE refer_table SET new_id = ?, new_code = ?, status = 1, parent_id = ?, refer_code = ?, tree_head_code = ?, tree_head_id = ? WHERE parent_code = ? AND status = 'false' LIMIT 1");
        $stmt->bind_param("isissis", $user_id, $my_number, $node['tree_head_id'], $referral_code, $node['tree_head'], $node['tree_head_id'], $refer_code);
        $stmt->execute();

       
        // Update parent_code and tree_head in MLM_users
        $stmt2 = $conn->prepare("UPDATE MLM_users SET parent_code = ?, tree_head = ? WHERE my_number = ? AND reference_number = ?");
        $stmt2->bind_param("ssss", $refer_code, $node['tree_head'], $my_number, $referral_code);
        $stmt2->execute();
        $stmt2->close();
  
        // Set message based on success of the operation
        $message = $stmt->affected_rows > 0
            ? 'Registration successful with tree node update! Please log in.'
            : 'Failed to update refer_table. No rows affected.';
        
        $stmt->close(); // Close the statement
    } else {
    

        // Update parent_code and tree_head in MLM_users
        $stmt2 = $conn->prepare("UPDATE MLM_users SET parent_code = ?, tree_head = ? WHERE my_number = ? AND reference_number = ?");
        $stmt2->bind_param("ssss", $referral_code, $node['tree_head'], $my_number, $referral_code);
        $stmt2->execute();
        $stmt2->close();
  
        $message = 'Registration successful! Please log in.';
        $stmt->close(); // Close the statement
    }
    
        $parent_code = !empty($refer_code) ? $referral_code : $referral_code;

        $stmt1 = $conn->prepare("UPDATE refer_table SET count = count + 1 WHERE new_code = ? ");
        $stmt1->bind_param("s", $parent_code);
        $stmt1->execute();
        $stmt1->close();
        
    $tree_head = $node['tree_head']; // Defined tree_head from $node

    distributeBonuses($conn, $my_number, $parent_code, $tree_head, $user_id);
    return $message;
}



// Handle approval action
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['approve_user_id'])) {
    $user_id = $_POST['approve_user_id'];
    $reference_number = $_POST['reference_number'];
    $admin_id = $_SESSION['id']; // Assuming the logged-in admin's ID is stored in session

    if (isAuthorized($conn, $admin_id)) {
        approveUser($conn, $user_id,$reference_number);
    } else {
        $unauthorized_user_id = $user_id; // Store the unauthorized attempt
        logError("Unauthorized attempt to approve user ID: " . $unauthorized_user_id);
    }
}

// Get all users details
$user_stmt = $conn->prepare("SELECT id, name, phone, reference_number, my_number,tree_head,parent_code, created_at, total_balance, approved FROM MLM_users");
$user_stmt->execute();
$user_result = $user_stmt->get_result();

// Fetch all users
$users = $user_result->fetch_all(MYSQLI_ASSOC);
$user_stmt->close();
?>


<?php include 'header.php'; ?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">User Management</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    All Users
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">User List</li>
        </ul>
    </div>

    <div class="card basic-data-table">

        <div class="card-body">

            <div class="d-flex flex-wrap align-items-center justify-content-between">
                <h6 class="text-lg mb-0">All Users</h6>

            </div>
            <br>
            <div style="overflow-x: auto; white-space: nowrap;">
                <table class="table bordered-table mb-0" id="dataTable" data-page-length='10' style="min-width: 800px;">
                    <thead>
                        <tr>
                            <th scope="col">S.L</th>
                            <th scope="col">ID</th>
                            <th scope="col">Name</th>
                            <th scope="col">Phone</th>
                            <th scope="col">Reference Number</th>
                            <th scope="col">Parent User</th>
                            <th scope="col">My Number</th>
                            <th scope="col">Created At</th>
                            <th scope="col">Approved</th>
                            <?php if ($admin_type == 1): // Show "Others" column only for admin type 1 ?>
                                <th scope="col">Others</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($users as $index => $user): ?>
                            <tr>
                                <td><?php echo $index + 1; ?></td>
                                <td><?php echo htmlspecialchars($user['id']); ?></td>
                                <td><?php echo htmlspecialchars($user['name']); ?></td>
                                <td><?php echo htmlspecialchars($user['phone']); ?></td>
                                <td><?php echo htmlspecialchars($user['reference_number']); ?></td>
                                <td><?php echo htmlspecialchars($user['parent_code'] == null ? "":$user['parent_code'] ); ?></td>
                                <td><?php echo htmlspecialchars($user['my_number'] == null ? "":$user['my_number']); ?></td>
                                <td><?php echo htmlspecialchars($user['created_at']); ?></td>
                                <td>
                                    <?php if (!$user['approved']): ?>
                                        <button class="btn btn-primary" data-toggle="modal"
                                            data-target="#approveModal-<?php echo $user['id']; ?>">Approve</button>
                                    <?php else: ?>
                                        <span class="text-success">Approved</span>
                                    <?php endif; ?>
                                </td>
                                <?php if ($admin_type == 1): // Show actions only for admin type 1 ?>
                                    <td>
                                        <a href="view-user.php?user_id=<?php echo $user['id']; ?>"
                                            class="w-32-px h-32-px bg-primary-light text-primary-600 rounded-circle d-inline-flex align-items-center justify-content-center">
                                            <iconify-icon icon="iconamoon:eye-light"></iconify-icon>
                                        </a>
                                        <a href="user-edit.php?user_id=<?php echo $user['id']; ?>"
                                            class="w-32-px h-32-px bg-success-focus text-success-main rounded-circle d-inline-flex align-items-center justify-content-center">
                                            <iconify-icon icon="lucide:edit"></iconify-icon>
                                        </a>
                                        <a href="user-report.php?user_id=<?php echo $user['id']; ?>"
                                            class="w-32-px h-32-px bg-danger-focus text-danger-main rounded-circle d-inline-flex align-items-center justify-content-center">
                                            <iconify-icon icon="mdi:repost"></iconify-icon>
                                        </a>
                                    </td>
                                <?php endif; ?>
                            </tr>

                            <!-- Approval Confirmation Modal -->
                            <div class="modal fade" id="approveModal-<?php echo $user['id']; ?>" tabindex="-1" role="dialog"
                                aria-labelledby="approveModalLabel-<?php echo $user['id']; ?>" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="approveModalLabel-<?php echo $user['id']; ?>">
                                                Confirm Approval</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <div class="modal-body">
                                            <?php
                                            $admin_id = $_SESSION['id'];
                                            $is_authorized = isAuthorized($conn, $admin_id);

                                            if (!$is_authorized): ?>
                                                <div class="alert alert-danger">
                                                    You are not authorized to approve users.
                                                </div>
                                            <?php else: ?>
                                                Are you sure you want to approve this user?
                                            <?php endif; ?>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-secondary"
                                                data-dismiss="modal">Cancel</button>
                                            <?php if (!$is_authorized): ?>
                                                <button type="button" class="btn btn-primary" disabled>You cannot
                                                    approve</button>
                                            <?php else: ?>
                                                <form method="POST" action="">
                                                    <input type="hidden" name="approve_user_id"
                                                        value="<?php echo $user['id']; ?>">
                                                        <input type="hidden" name="reference_number"
                                                        value="<?php echo $user['reference_number']; ?>">
                                                    <button type="submit" class="btn btn-primary">Approve</button>
                                                </form>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>

                        <?php endforeach; ?>
                    </tbody>
                </table>

            </div>
        </div>
    </div>
</div>

<?php include 'footer.php';

?>



<link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>