<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);
session_start();

if (!isset($_SESSION['id'])) {
    header("Location: index.php");
    exit;
}

include 'db.php';

include 'header.php';

// Handle withdrawal approval and insert into wallet_transactions
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['approve'])) {
    // Get the withdrawal record using the withdrawal amount and user id passed in the modal
    $withdrawalAmount = $_POST['withdrawal_amount'];
    $userId = $_POST['user_id'];

    // Fetch the user_id from the payment_withdrawals table
    $fetchUserQuery = "SELECT user_id FROM payment_withdrawals WHERE withdrawal_amount = ? AND user_id = ?";
    $fetchStmt = $conn->prepare($fetchUserQuery);
    $fetchStmt->bind_param("ds", $withdrawalAmount, $userId);
    $fetchStmt->execute();
    $fetchResult = $fetchStmt->get_result();

    if ($fetchResult->num_rows > 0) {
        $withdrawalRecord = $fetchResult->fetch_assoc();
        $userId = $withdrawalRecord['user_id']; // Fetch user_id from the withdrawal record
        $description = "Successful withdrawal amount of $withdrawalAmount";
        $walletType = 'withdrawal';

        // Insert into wallet_transactions
        // $insertQuery = "INSERT INTO `wallet_transactions` (`user_id`, `amount`, `description`, `created_at`, `wallet_type`) 
        //                 VALUES (?, ?, ?, NOW(), ?)";
        // $stmt = $conn->prepare($insertQuery);
        // $stmt->bind_param("sdss", $userId, $withdrawalAmount, $description, $walletType);
        
        if ($stmt->execute()) {
            // Update the payment_withdrawals table to set type to 'withdrawal'
            $updateQuery = "UPDATE `payment_withdrawals` SET `type` = 'withdrawal' WHERE `user_id` = ? AND `withdrawal_amount` = ?";
            $updateStmt = $conn->prepare($updateQuery);
            $updateStmt->bind_param("sd", $userId, $withdrawalAmount);
            
            if ($updateStmt->execute()) {
                echo "<script>$('#successModal').modal('show');</script>";
            } else {
                echo "<script>alert('Error updating withdrawal type: " . $updateStmt->error . "');</script>";
            }
            $updateStmt->close();
        } else {
            echo "<script>alert('Error inserting into wallet_transactions: " . $stmt->error . "');</script>";
        }
        $stmt->close();
    } else {
        echo "<script>alert('No matching withdrawal record found.');</script>";
    }
    $fetchStmt->close();
}


// Fetch payment withdrawals with type 'pending'
$query = "SELECT `id`, `user_id`, `user_name`, `bank_name`, `bank_number`, `withdrawal_amount`, `type`, `created_at` 
          FROM `payment_withdrawals` 
          WHERE `type` = 'pending'";

$result = $conn->query($query);

// Check for query errors
if (!$result) {
    die("Query failed: " . $conn->error);
}

?>
 <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script> 

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">User Management</h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    All Users
                </a>
            </li>
            <li>-</li>
            <li class="fw-medium">Withdrawal List</li>
        </ul>
    </div>

    <div class="card basic-data-table">
        <div class="card-header">
            <h5 class="card-title mb-0">Pending Withdrawals</h5>
        </div>
        <div class="card-body">
            <table class="table bordered-table mb-0" id="dataTable" data-page-length='10'>
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">User ID</th>
                        <th scope="col">User Name</th>
                        <th scope="col">Bank Name</th>
                        <th scope="col">Bank Number</th>
                        <th scope="col">Withdrawal Amount</th>
                        <th scope="col">Type</th>
                        <th scope="col">Created At</th>
                        <th scope="col">Action</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($result->num_rows > 0): ?>
                        <?php while ($withdrawal = $result->fetch_assoc()): ?>
                        <tr>
                            <td>
                                <div class='form-check style-check d-flex align-items-center'>
                                    <input class='form-check-input' type='checkbox'>
                                    <label class='form-check-label'><?php echo htmlspecialchars($withdrawal['id']); ?></label>
                                </div>
                            </td>
                            <td><?php echo htmlspecialchars($withdrawal['user_id']); ?></td>
                            <td><?php echo htmlspecialchars($withdrawal['user_name']); ?></td>
                            <td><?php echo htmlspecialchars($withdrawal['bank_name']); ?></td>
                            <td><?php echo htmlspecialchars($withdrawal['bank_number']); ?></td>
                            <td><?php echo htmlspecialchars(number_format($withdrawal['withdrawal_amount'], 2)); ?></td>
                            <td><?php echo htmlspecialchars($withdrawal['type']); ?></td>
                            <td><?php echo htmlspecialchars(date('d M Y', strtotime($withdrawal['created_at']))); ?></td>
                            <td>
                                <button class="btn btn-success btn-sm" 
                                        data-toggle="modal" 
                                        data-target="#confirmModal" 
                                        data-user-id="<?php echo htmlspecialchars($withdrawal['user_id']); ?>" 
                                        data-withdrawal-amount="<?php echo htmlspecialchars($withdrawal['withdrawal_amount']); ?>">Approve</button>
                            </td>
                        </tr>
                        <?php endwhile; ?>
                    <?php else: ?>
                        
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- Confirmation Modal -->
<div class="modal fade" id="confirmModal" aria-labelledby="confirmModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="confirmModalLabel">Confirm Approval</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span>&times;</span>
                </button>
            </div>
            <div class="modal-body">
                Are you sure you want to approve this withdrawal?
            </div>
            <div class="modal-footer">
                <form method="POST" action="">
                    <input type="hidden" name="user_id" id="modalUserId">
                    <input type="hidden" name="withdrawal_amount" id="modalWithdrawalAmount">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                    <button type="submit" name="approve" class="btn btn-success">Approve</button>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Success Modal -->
<div class="modal fade" id="successModal"  aria-labelledby="successModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="successModalLabel">Success</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span>&times;</span>
                </button>
            </div>
            <div class="modal-body">
                Withdrawal approved successfully!
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
            </div>
        </div>
    </div>
</div>

<script>
// Set user ID and withdrawal amount in the modal before showing it
$('#confirmModal').on('show.bs.modal', function (event) {
    var button = $(event.relatedTarget); // Button that triggered the modal
    var userId = button.data('user-id'); // Extract info from data-* attributes
    var withdrawalAmount = button.data('withdrawal-amount'); // Extract info from data-* attributes

    // Update the modal's content.
    var modal = $(this);
    modal.find('#modalUserId').val(userId);
    modal.find('#modalWithdrawalAmount').val(withdrawalAmount);
});


</script>

<?php include 'footer.php'; ?>

<?php
$conn->close();
?>
