<?php
session_start(); 

include 'db.php'; 
include 'header.php';

if (!isset($_SESSION['user_id'])) {
    echo "You are not logged in.";
    exit;
}

$userId = $_SESSION['user_id'];

// Fetching user details based on user ID
$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number']; 
} else {
    echo "No user found with the provided ID.";
    exit;
}

// Function to fetch total amounts based on wallet type and optionally a date condition
function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";

    // Append date condition if provided
    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0; // Return total or 0 if null
}

// Fetch balances and withdrawals with error handling
$userBalance = fetchTotalAmount($conn, $userId, 'add'); // Total balance
$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal'); // Total withdrawals

// Ensure withdrawals are treated as positive for calculation
$userWithdraw = abs($userWithdraw); // Convert withdrawals to positive if needed

// Calculate net balance
$netBalance = $userBalance - $userWithdraw; // Correctly calculate net balance

// Fetch today's balance and withdrawals
$todayCondition = 'AND DATE(created_at) = CURDATE()'; // Condition for today's date
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition); // Today's deposits
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition); // Today's withdrawals

// Fetch reference user's total balance
$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

// Fetch count of users who used the current user's reference number
$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

// Fetch count of users referred by the current user today
$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;

// You can now display user information and statistics
// echo "Welcome, User ID: " . htmlspecialchars($user['id']) . " with Mobile Number: " . htmlspecialchars($user['phone']);

?>


<!-- App Capsule -->
<div id="appCapsule">

    <!-- Wallet Card -->
    <div class="section wallet-card-section pt-1">
        <div class="wallet-card">
            <!-- Balance -->
            <div class="balance">
                <div class="left">
                    <span class="title">Total Balance</span>
                    <h1 class="total">₹<?php echo htmlspecialchars($netBalance); ?></h1>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            ₹ <?php echo htmlspecialchars($todayBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        Today
                    </p>
                </div>
                <div class="right">
                    <a href="#" class="button" data-bs-toggle="modal" data-bs-target="#withdrawalModal">
                        <ion-icon name="add-outline"></ion-icon>
                    </a>
                </div>
            </div>
        </div>
    </div>
    <!-- Wallet Card -->

    <!-- Stats -->
    <div class="section">
        <div class="row mt-2">
            <div class="col-6">
                <div class="stat-box">
                    <div class="title">Total Withdrawals</div>
                    <div class="value text-success">₹<?php echo htmlspecialchars($userWithdraw); ?></div>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-danger-focus px-6 py-2 rounded-2 fw-medium text-danger-main text-sm d-flex align-items-center gap-8">
                            ₹<?php echo htmlspecialchars($todayWithdraw); ?> <i class="ri-arrow-down-line"></i>
                        </span> Today
                    </p>
                </div>
            </div>
            <div class="col-6">
                <div class="stat-box">
                    <div class="title">Users Referred by</div>
                    <div class="value text-danger"><?php echo htmlspecialchars($refUserCount); ?></div>
                    <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayRefUserCount); ?> <i class="ri-user-add-line"></i>
                        </span> Today
                    </p>
                </div>
            </div>
        </div>
    </div>
    <!-- * Stats -->

    <?php include 'chart.php'; ?>

    <!-- Transactions -->
    <div class="section mt-4">
        <div class="section-heading">
            <h2 class="title">Transactions</h2>
            <a href="transactions.php" class="link">View All</a>
        </div>
        <div class="transactions">
            <?php
            // Prepare query to fetch the last 10 transactions for the user
            $transactionsQuery = "SELECT * FROM `wallet_transactions` WHERE `user_id` = ? ORDER BY `created_at` DESC LIMIT 10";
            $stmt = $conn->prepare($transactionsQuery);
            $stmt->bind_param("i", $userId); // Bind user ID as integer
            $stmt->execute();
            $transactions = $stmt->get_result();

            // Check if there are any transactions to display
            if ($transactions->num_rows > 0) {
                // Loop through each transaction and display the details
                while ($transaction = $transactions->fetch_assoc()) {
                    ?>
                    <!-- item -->
                    <a href="transactions.php" class="item">
                        <div class="detail">
                            <div>
                                <strong><?php echo htmlspecialchars($transaction['description']); // Assuming there is a description field ?></strong>
                                <p><?php echo htmlspecialchars($transaction['created_at']); // Show the date/time of the transaction ?></p>
                            </div>
                        </div>
                        <div class="right">
                            <div class="price">₹ <?php echo htmlspecialchars($transaction['amount']); // Show the transaction amount ?></div>
                        </div>
                    </a>
                    <!-- * item -->
                    <?php
                }
            } else {
                echo "<p>No transactions available for this user.</p>";
            }
            ?>
        </div>
    </div>
    <!-- * Transactions -->

</div>

<?php include 'footer.php'; ?>



<!-- Withdrawal Modal -->
<div class="modal fade" id="withdrawalModal" tabindex="-1" aria-labelledby="withdrawalModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="withdrawalModalLabel">Withdrawal Details</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="withdrawalForm" method="POST" action="process_withdrawal.php" onsubmit="return validateWithdrawal();">
                    <div class="mb-3">
                        <label for="userName" class="form-label">User Name *</label>
                        <input type="text" class="form-control" id="userName" name="userName" required>
                    </div>
                    <div class="mb-3">
                        <label for="bankName" class="form-label">Bank Name *</label>
                        <input type="text" class="form-control" id="bankName" name="bankName" required>
                    </div>
                    <div class="mb-3">
                        <label for="bankNumber" class="form-label">Bank Number *</label>
                        <input type="text" class="form-control" id="bankNumber" name="bankNumber" pattern="\d{1,16}" maxlength="16" title="Only digits are allowed. Maximum 16 digits." required>
                        <div id="bankNumberError" class="text-danger" style="display: none;"></div>
                    </div>
                    <div class="mb-3">
                        <label for="branch" class="form-label">Branch *</label>
                        <input type="text" class="form-control" id="branch" name="branch" required>
                    </div>
                    <div class="mb-3">
                        <label for="withdrawalAmount" class="form-label">Withdrawal Amount *</label>
                        <div id="error-message" class="text-danger" style="display: none;"></div>
                        <input type="number" class="form-control" id="withdrawalAmount" name="withdrawalAmount" step="0.01" required>
                    </div>
                    <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($userId); ?>">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary" form="withdrawalForm">Withdraw</button>
            </div>
        </div>
    </div>
</div>

<script>
    function validateWithdrawal() {
        const withdrawalAmount = parseFloat(document.getElementById('withdrawalAmount').value);
        const netBalance = parseFloat(<?php echo htmlspecialchars($userBalance); ?>); // Ensure you pass the user's balance from PHP
        const bankNumber = document.getElementById('bankNumber').value;

        // Define the minimum balance that must remain after withdrawal
        const minimumBalance = 200;

        // Clear any previous error messages
        const errorMessageElement = document.getElementById('error-message');
        errorMessageElement.style.display = 'none';
        errorMessageElement.innerText = '';

        const bankNumberErrorElement = document.getElementById('bankNumberError');
        bankNumberErrorElement.style.display = 'none';
        bankNumberErrorElement.innerText = '';

        // Check if the user has 200 or less balance
        if (netBalance <= minimumBalance) {
            errorMessageElement.innerText = 'Your balance must be above ₹200.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the withdrawal amount is less than 100
        if (withdrawalAmount < 100) {
            errorMessageElement.innerText = 'Minimum withdrawal: ₹100.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }
        
        // Check if the withdrawal amount exceeds the available balance minus the minimum balance requirement
        if (withdrawalAmount > (netBalance - minimumBalance)) {
            errorMessageElement.innerText = 'You can only withdraw up to ₹' + (netBalance - minimumBalance) + '.';
            errorMessageElement.style.display = 'block';
            return false; // Prevent form submission
        }

        // Check if the bank number is valid
        const bankNumberPattern = /^\d{1,16}$/;
        if (!bankNumberPattern.test(bankNumber)) {
            bankNumberErrorElement.innerText = 'Bank number must be 1 to 16 digits long and contain only numbers.';
            bankNumberErrorElement.style.display = 'block';
            return false; // Prevent form submission
        }

        return true; // Allow form submission if all validations pass
    }
</script>
