<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

session_start();
include 'header.php'; 
include 'db.php'; 

// Set the user ID
$user_id = 120; // For this example, we're using a static user ID of 120

// Get user data from the database
$query = "SELECT id, name, phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo "<p>User not found.</p>";
    exit;
}

// Initialize a message variable
$message = '';

// Update user profile if form is submitted
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $updated_name = trim($_POST['name']);
    $updated_phone = trim($_POST['phone']);

    // Validate input
    if (empty($updated_name) || empty($updated_phone)) {
        $message = "<p class='text-danger'>Please fill in all fields.</p>";
    } else {
        // Update user info in the database
        $update_query = "UPDATE MLM_users SET name = ?, phone = ? WHERE id = ?";
        $update_stmt = $conn->prepare($update_query);
        $update_stmt->bind_param("ssi", $updated_name, $updated_phone, $user_id);

        if ($update_stmt->execute()) {
            $message = "<p class='text-success'>Profile updated successfully.</p>";
            // Refresh the user data after update
            $user['name'] = $updated_name;
            $user['phone'] = $updated_phone;
        } else {
            $message = "<p class='text-danger'>Error updating profile. Please try again.</p>";
        }
    }
}
?>

<div id="appCapsule">
    <div class="section mt-2 text-center">
        <h1>Profile</h1>
        <h4>Edit your details</h4>
    </div>
    <div class="section mb-5 p-2">
        <div class="row">
            <!-- User Details Column -->
            <div class="col-12 col-md-6 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5>User Details</h5>
                        <p><strong>Name:</strong> <?php echo htmlspecialchars($user['name']); ?></p>
                        <p><strong>Phone Number:</strong> <?php echo htmlspecialchars($user['phone']); ?></p>
                        <p><strong>Reference Number:</strong> <?php echo htmlspecialchars($user['reference_number']); ?></p>
                        <p><strong>My Number:</strong> <?php echo htmlspecialchars($user['my_number']); ?></p>
                        <p><strong>Created At:</strong> <?php echo htmlspecialchars($user['created_at']); ?></p>
                        <p><strong>Total Balance:</strong> <?php echo htmlspecialchars($user['total_balance']); ?></p>
                        <p><strong>Approved:</strong> <?php echo htmlspecialchars($user['approved'] ? 'Yes' : 'No'); ?></p>
                    </div>
                </div>
            </div>

            <!-- Edit Profile Form Column -->
            <div class="col-12 col-md-6 mb-4">
                <form action="" method="POST">
                    <div class="card">
                        <div class="card-body">
                            <h5>Edit Profile</h5>
                            <?php if ($message): ?>
                                <div class="message">
                                    <?php echo $message; ?>
                                </div>
                            <?php endif; ?>
                            <div class="form-group basic">
                                <div class="input-wrapper">
                                    <label class="label" for="name">Name</label>
                                    <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($user['name']); ?>" placeholder="Your name">
                                </div>
                            </div>

                            <div class="form-group basic">
                                <div class="input-wrapper">
                                    <label class="label" for="phone">Phone Number</label>
                                    <input type="text" class="form-control" id="phone" name="phone" value="<?php echo htmlspecialchars($user['phone']); ?>" placeholder="Your phone number">
                                </div>
                            </div>

                            <div class="form-top-group">
                                <button type="submit" class="btn btn-primary btn-block btn-lg">Update Profile</button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>
